@@ -2,9 +2,11 @@
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Georg Ehrke <oc.list@georgehrke.com>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Lukas Reschke <lukas@statuscode.ch>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
  * @license AGPL-3.0
@@ -19,19 +21,25 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
 namespace OCA\DAV\CalDAV;
 
+use OCA\DAV\AppInfo\PluginManager;
+use OCA\DAV\CalDAV\Integration\ExternalCalendar;
+use OCA\DAV\CalDAV\Integration\ICalendarProvider;
+use OCA\DAV\CalDAV\Trashbin\TrashbinHome;
+use Psr\Log\LoggerInterface;
 use Sabre\CalDAV\Backend\BackendInterface;
 use Sabre\CalDAV\Backend\NotificationSupport;
 use Sabre\CalDAV\Backend\SchedulingSupport;
 use Sabre\CalDAV\Backend\SubscriptionSupport;
 use Sabre\CalDAV\Schedule\Inbox;
 use Sabre\CalDAV\Subscriptions\Subscription;
-use Sabre\DAV\Exception\NotFound;
 use Sabre\DAV\Exception\MethodNotAllowed;
+use Sabre\DAV\Exception\NotFound;
+use Sabre\DAV\INode;
 use Sabre\DAV\MkCol;
 
 class CalendarHome extends \Sabre\CalDAV\CalendarHome {
@@ -42,10 +50,25 @@ class CalendarHome extends \Sabre\CalDAV\CalendarHome {
 	/** @var \OCP\IConfig */
 	private $config;
 
-	public function __construct(BackendInterface $caldavBackend, $principalInfo) {
+	/** @var PluginManager */
+	private $pluginManager;
+
+	/** @var bool */
+	private $returnCachedSubscriptions = false;
+
+	/** @var LoggerInterface */
+	private $logger;
+	private ?array $cachedChildren = null;
+
+	public function __construct(BackendInterface $caldavBackend, $principalInfo, LoggerInterface $logger) {
 		parent::__construct($caldavBackend, $principalInfo);
 		$this->l10n = \OC::$server->getL10N('dav');
 		$this->config = \OC::$server->getConfig();
+		$this->pluginManager = new PluginManager(
+			\OC::$server,
+			\OC::$server->getAppManager()
+		);
+		$this->logger = $logger;
 	}
 
 	/**
@@ -58,10 +81,13 @@ class CalendarHome extends \Sabre\CalDAV\CalendarHome {
 	/**
 	 * @inheritdoc
 	 */
-	function createExtendedCollection($name, MkCol $mkCol) {
-		$reservedNames = [BirthdayService::BIRTHDAY_CALENDAR_URI];
+	public function createExtendedCollection($name, MkCol $mkCol): void {
+		$reservedNames = [
+			BirthdayService::BIRTHDAY_CALENDAR_URI,
+			TrashbinHome::NAME,
+		];
 
-		if (in_array($name, $reservedNames)) {
+		if (\in_array($name, $reservedNames, true) || ExternalCalendar::doesViolateReservedName($name)) {
 			throw new MethodNotAllowed('The resource you tried to create has a reserved name');
 		}
 
@@ -71,11 +97,14 @@ class CalendarHome extends \Sabre\CalDAV\CalendarHome {
 	/**
 	 * @inheritdoc
 	 */
-	function getChildren() {
+	public function getChildren() {
+		if ($this->cachedChildren) {
+			return $this->cachedChildren;
+		}
 		$calendars = $this->caldavBackend->getCalendarsForUser($this->principalInfo['uri']);
 		$objects = [];
 		foreach ($calendars as $calendar) {
-			$objects[] = new Calendar($this->caldavBackend, $calendar, $this->l10n, $this->config);
+			$objects[] = new Calendar($this->caldavBackend, $calendar, $this->l10n, $this->config, $this->logger);
 		}
 
 		if ($this->caldavBackend instanceof SchedulingSupport) {
@@ -88,20 +117,39 @@ class CalendarHome extends \Sabre\CalDAV\CalendarHome {
 			$objects[] = new \Sabre\CalDAV\Notifications\Collection($this->caldavBackend, $this->principalInfo['uri']);
 		}
 
+		if ($this->caldavBackend instanceof CalDavBackend) {
+			$objects[] = new TrashbinHome($this->caldavBackend, $this->principalInfo);
+		}
+
 		// If the backend supports subscriptions, we'll add those as well,
 		if ($this->caldavBackend instanceof SubscriptionSupport) {
 			foreach ($this->caldavBackend->getSubscriptionsForUser($this->principalInfo['uri']) as $subscription) {
-				$objects[] = new Subscription($this->caldavBackend, $subscription);
+				if ($this->returnCachedSubscriptions) {
+					$objects[] = new CachedSubscription($this->caldavBackend, $subscription);
+				} else {
+					$objects[] = new Subscription($this->caldavBackend, $subscription);
+				}
 			}
 		}
 
+		foreach ($this->pluginManager->getCalendarPlugins() as $calendarPlugin) {
+			/** @var ICalendarProvider $calendarPlugin */
+			$calendars = $calendarPlugin->fetchAllForCalendarHome($this->principalInfo['uri']);
+			foreach ($calendars as $calendar) {
+				$objects[] = $calendar;
+			}
+		}
+
+		$this->cachedChildren = $objects;
 		return $objects;
 	}
 
 	/**
-	 * @inheritdoc
+	 * @param string $name
+	 *
+	 * @return INode
 	 */
-	function getChild($name) {
+	public function getChild($name) {
 		// Special nodes
 		if ($name === 'inbox' && $this->caldavBackend instanceof SchedulingSupport) {
 			return new Inbox($this->caldavBackend, $this->principalInfo['uri']);
@@ -110,23 +158,44 @@ class CalendarHome extends \Sabre\CalDAV\CalendarHome {
 			return new Outbox($this->config, $this->principalInfo['uri']);
 		}
 		if ($name === 'notifications' && $this->caldavBackend instanceof NotificationSupport) {
-			return new \Sabre\CalDAv\Notifications\Collection($this->caldavBackend, $this->principalInfo['uri']);
+			return new \Sabre\CalDAV\Notifications\Collection($this->caldavBackend, $this->principalInfo['uri']);
+		}
+		if ($name === TrashbinHome::NAME && $this->caldavBackend instanceof CalDavBackend) {
+			return new TrashbinHome($this->caldavBackend, $this->principalInfo);
 		}
 
 		// Calendars
 		foreach ($this->caldavBackend->getCalendarsForUser($this->principalInfo['uri']) as $calendar) {
 			if ($calendar['uri'] === $name) {
-				return new Calendar($this->caldavBackend, $calendar, $this->l10n, $this->config);
+				return new Calendar($this->caldavBackend, $calendar, $this->l10n, $this->config, $this->logger);
 			}
 		}
 
 		if ($this->caldavBackend instanceof SubscriptionSupport) {
 			foreach ($this->caldavBackend->getSubscriptionsForUser($this->principalInfo['uri']) as $subscription) {
 				if ($subscription['uri'] === $name) {
+					if ($this->returnCachedSubscriptions) {
+						return new CachedSubscription($this->caldavBackend, $subscription);
+					}
+
 					return new Subscription($this->caldavBackend, $subscription);
 				}
 			}
+		}
 
+		if (ExternalCalendar::isAppGeneratedCalendar($name)) {
+			[$appId, $calendarUri] = ExternalCalendar::splitAppGeneratedCalendarUri($name);
+
+			foreach ($this->pluginManager->getCalendarPlugins() as $calendarPlugin) {
+				/** @var ICalendarProvider $calendarPlugin */
+				if ($calendarPlugin->getAppId() !== $appId) {
+					continue;
+				}
+
+				if ($calendarPlugin->hasCalendarInCalendarHome($this->principalInfo['uri'], $calendarUri)) {
+					return $calendarPlugin->getCalendarInCalendarHome($this->principalInfo['uri'], $calendarUri);
+				}
+			}
 		}
 
 		throw new NotFound('Node with name \'' . $name . '\' could not be found');
@@ -137,8 +206,12 @@ class CalendarHome extends \Sabre\CalDAV\CalendarHome {
 	 * @param integer|null $limit
 	 * @param integer|null $offset
 	 */
-	function calendarSearch(array $filters, $limit=null, $offset=null) {
+	public function calendarSearch(array $filters, $limit = null, $offset = null) {
 		$principalUri = $this->principalInfo['uri'];
 		return $this->caldavBackend->calendarSearch($principalUri, $filters, $limit, $offset);
 	}
+
+	public function enableCachedSubscriptionsForThisRequest() {
+		$this->returnCachedSubscriptions = true;
+	}
 }
