@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
-    "Storage invalid" : "ストレージが無効です",
-    "Unknown error" : "不明なエラー",
     "File could not be found" : "ファイルを見つけられませんでした",
     "Move or copy" : "移動またはコピー",
     "Download" : "ダウンロード",
@@ -13,7 +10,6 @@ OC.L10N.register(
     "Show grid view" : "グリッドビューで表示",
     "Home" : "ホーム",
     "Close" : "閉じる",
-    "Favorites" : "お気に入り",
     "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
     "This will stop your current uploads." : "現在のアップロードが停止されます。",
     "Upload cancelled." : "アップロードはキャンセルされました。",
@@ -26,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "不明なエラーが発生しました",
     "File could not be uploaded" : "ファイルをアップロードできませんでした",
     "Uploading …" : "アップロード中...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "アップロード中… ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
     "Uploading that item is not supported" : "そのアイテムのアップロードに対応していません",
     "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
@@ -36,6 +34,8 @@ OC.L10N.register(
     "Move" : "移動",
     "Copy" : "コピー",
     "Choose target folder" : "ターゲットフォルダーを選択",
+    "Set reminder" : "リマインダーを設定",
+    "Edit locally" : "ローカルで編集",
     "Open" : "開く",
     "Delete file" : "ファイルを削除",
     "Delete folder" : "フォルダーを削除",
@@ -52,6 +52,7 @@ OC.L10N.register(
     "Unable to determine date" : "更新日不明",
     "This operation is forbidden" : "この操作は禁止されています",
     "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
+    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
     "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
     "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
     "copy" : "コピー",
@@ -59,6 +60,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
     "Copied {origin} inside {destination}" : "コピー先{origin} {destination}内",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "コピー先{origin}と{nbfiles}他のファイル{destination}",
+    "Failed to redirect to client" : "クライアントへリダイレクトできませんでした",
     "{newName} already exists" : "{newName} はすでに存在します",
     "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
@@ -79,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
     "You do not have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
     "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
+    "New" : "新規作成",
     "New file/folder menu" : "新規ファイル/フォルダメニュー",
     "Select file range" : "ファイルを範囲選択",
     "{used}%" : "{used}%",
@@ -98,14 +101,14 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "ストレージがほぼいっぱい ({usedSpacePercent}％) です　",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : [" \"{filter}\" にマッチ"],
     "View in folder" : "フォルダー内で表示",
-    "Copied!" : "コピー完了",
-    "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "直接リンクがコピーされました（ただしこのファイルやフォルダにアクセスできる人だけが使用可能です）",
     "Path" : "Path",
     "_%n byte_::_%n bytes_" : ["%n バイト"],
     "Favorited" : "お気に入り済",
     "Favorite" : "お気に入り",
-    "You can only favorite a single file or folder at a time" : "お気に入りに追加できるファイルまたはフォルダーは一度に1つまでです",
+    "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
     "New folder" : "新しいフォルダー",
+    "Create new folder" : "新しいフォルダーを作成",
     "Upload file" : "ファイルをアップロード",
     "Recent" : "最新",
     "Not favorited" : "お気に入りではありません",
@@ -116,6 +119,7 @@ OC.L10N.register(
     "Removed from favorites" : "お気に入りから削除",
     "You added {file} to your favorites" : "{file} をお気に入りに追加しました",
     "You removed {file} from your favorites" : "{file} をお気に入りから削除しました",
+    "Favorites" : "お気に入り",
     "File changes" : "ファイル更新",
     "Created by {user}" : "{user} が作成しました",
     "Changed by {user}" : "{user} が更新しました",
@@ -152,8 +156,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>お気に入り</strong>にファイルが追加または削除されたとき",
     "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーが<strong>変更</strong>されたとき",
     "A favorite file or folder has been <strong>changed</strong>" : "お気に入りのファイルまたはフォルダーが <strong>変更</strong>されたとき",
-    "All files" : "すべてのファイル",
-    "Unlimited" : "無制限",
     "Upload (max. %s)" : "アップロード ( 最大 %s )",
     "Accept" : "承諾",
     "Reject" : "拒否",
@@ -167,61 +169,147 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{user} からの {path} の所有権転送が完了しました。",
     "in %s" : "%s で",
     "File Management" : "ファイル管理",
+    "Reload current directory" : "カレントディレクトリの再読み込み",
+    "Go to the \"{dir}\" directory" : "\"{dir}\" ディレクトリに移動する",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行された",
+    "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
+    "Select the row for {displayName}" : "{displayName} の行を選択する",
+    "Rename file" : "ファイル名の変更",
+    "File name" : "ファイル名",
+    "Folder name" : "フォルダー名",
+    "This node is unavailable" : "このノードは利用できません",
+    "Download file {name}" : "ファイル {name} をダウンロード",
+    "\"{name}\" is not an allowed filetype." : "\"{name}\" は許可されたファイルタイプではありません。",
+    "{newName} already exists." : "{newName} すでに存在しています。",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}\"はファイル名には使用できません。",
+    "Name cannot be empty" : "名前は空にできません",
+    "Another entry with the same name already exists" : "同じ名前の別のエントリがすでに存在しています",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
+    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" の名前を変更できませんでした、それは既に存在しません。",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" という名前は \"{dir}\" フォルダですでに使用されています。別の名前を選択してください。",
+    "Could not rename \"{oldName}\"" : "\"{oldName}\" の名前を変更できませんでした。",
+    "A long time ago" : "ずっと以前に",
+    "Could not copy {file}. {message}" : "{file} をコピーできませんでした。 {message}",
+    "Could not move {file}. {message}" : "{file} を移動できませんでした。 {message}",
+    "Total rows summary" : "総行数のサマリー",
+    "Select all" : "すべて選択",
+    "Unselect all" : "すべて選択解除",
+    "\"{displayName}\" failed on some elements " : "いくつかの要素で \"{displayName}\" が失敗しました。",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" バッチアクションが正常に実行されました。",
+    "List of files and folders." : "ファイルとフォルダの一覧。",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
+    "{summaryFile} and {summaryFolder}" : "{summaryFile} と {summaryFolder}",
+    "File not found" : "ファイルが見つかりません",
+    "_{count} file_::_{count} files_" : ["{count} ファイル"],
+    "_{count} folder_::_{count} folders_" : ["{count} フォルダ"],
+    "Storage informations" : "ストレージ情報",
+    "{usedQuotaByte} used" : "{usedQuotaByte} 使用されています",
+    "{relative}% used" : "{relative}% 使用されています",
+    "Could not refresh storage stats" : "ストレージの状態を更新できませんでした",
     "Transfer ownership of a file or folder" : "ファイルまたはフォルダーの所有権を譲渡する",
     "Choose file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
     "Change" : "変更",
     "New owner" : "新しい所有者",
-    "Search users" : "ユーザーを検索",
     "Choose a file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
     "Transfer" : "転送",
     "Transfer {path} to {userid}" : "{path} を {userid} に転送する",
     "Invalid path selected" : "無効なパスが選択されました",
+    "Unknown error" : "不明なエラー",
     "Ownership transfer request sent" : "所有権転送のリクエストを送信しました",
     "Cannot transfer ownership of a file or folder you do not own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
+    "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
+    "Loading current folder" : "現在のフォルダの読み込み中",
+    "No files in here" : "ファイルがありません",
+    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
+    "Go to the previous folder" : "前のフォルダへ移動",
+    "Go back" : "戻る",
+    "Share" : "共有",
+    "Shared by link" : "URLリンクで共有中",
+    "Shared" : "共有中",
+    "Open the files app settings" : "ファイルアプリの設定を開く",
+    "Files settings" : "ファイルの設定",
+    "File cannot be accessed" : "ファイルにアクセスできません",
+    "You might not have have permissions to view it, ask the sender to share it" : "閲覧権限がない可能性があるため、送信者に共有を依頼してください",
+    "Sort favorites first" : "お気に入りを最初に並べる",
+    "Show hidden files" : "隠しファイルを表示",
+    "Crop image previews" : "プレビュー画像を切り抜く",
+    "Additional settings" : "追加設定",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "クリップボードにコピー",
+    "Use this address to access your Files via WebDAV" : "このアドレスを使用すれば、WebDAV経由でファイルにアクセスできます",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FAを有効にしている場合は、ここをクリックして新しいアプリのパスワードを作成し、使用する必要があります。",
+    "Clipboard is not available" : "クリップボードは利用できません",
+    "WebDAV URL copied to clipboard" : "WebDAVのURLがクリップボードにコピーされました",
     "Unable to change the favourite state of the file" : "ファイルのお気に入りの状態を変更できません",
     "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
     "Pick a template for {name}" : "{name} のテンプレートを選択してください",
-    "Cancel" : "キャンセル",
     "Create" : "作成",
     "Create a new file with the selected template" : "選択したテンプレートを使用して新しいファイルを作成します",
     "Creating file" : "ファイル作成",
     "Blank" : "ブランク",
     "Unable to create new file from template" : "テンプレートから新しいファイルを作成できません",
-    "Set up templates folder" : "テンプレートフォルダーを設定",
+    "Delete permanently" : "永久に削除",
+    "Destination is not a folder" : "宛先がフォルダではありません",
+    "This file/folder is already in that directory" : "このファイル/フォルダはすでにそのディレクトリにあります",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "ファイル/フォルダをそれ自身の上に移動したり、それ自身のサブフォルダに移動したりすることはできません。",
+    "A file or folder with that name already exists in this folder" : "その名前のファイルまたはフォルダが、このフォルダに既に存在します",
+    "The files is locked" : "ファイルはロックされています",
+    "The file does not exist anymore" : "ファイルはもう存在しません",
+    "Chose destination" : "目的地を選ぶ",
+    "Copy to {target}" : "{target} にコピー",
+    "Move to {target}" : "{target} に移動",
+    "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
+    "Open folder {displayName}" : "フォルダ {displayName} を開く",
+    "Open in Files" : "ファイルアプリで開く",
+    "Open details" : "詳細を開く",
+    "Create new templates folder" : "新しいテンプレートフォルダーを作成",
     "Templates" : "テンプレート",
     "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
+    "Created new folder \"{name}\"" : "新規フォルダ \"{name}\" を作成した",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} フォルダ"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ファイル"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ファイルと {folderCount} フォルダ"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ファイルと 1 フォルダ"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} ファイルと {folderCount} フォルダ",
+    "List of favorites files and folders." : "お気に入りのファイルやフォルダーの一覧",
+    "No favorites yet" : "まだお気に入りはありません",
+    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
+    "All files" : "すべてのファイル",
+    "List of your files and folders." : "ファイルやフォルダーの一覧",
+    "List of recently modified files and folders." : "最近変更されたファイルとフォルダーのリスト",
+    "No recently modified files" : "最近更新されたファイルはありません",
+    "Files and folders you recently modified will show up here." : "最近変更したファイルやフォルダーがここに表示されます。",
+    "Toggle %1$s sublist" : "サブリスト %1$s を切り替え",
+    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
+    "Upload too large" : "アップロードには大きすぎます。",
+    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
+    "Text file" : "テキストファイル",
+    "New text file.txt" : "新規のテキストファイル作成",
+    "Storage invalid" : "ストレージが無効です",
+    "You can only favorite a single file or folder at a time" : "お気に入りに追加できるファイルまたはフォルダーは一度に1つまでです",
+    "Unlimited" : "無制限",
+    "Search users" : "ユーザーを検索",
+    "Cancel" : "キャンセル",
+    "Set up templates folder" : "テンプレートフォルダーを設定",
     "%s used" : "%s 使用中",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%2$s 中%1$s 使用中",
-    "Files settings" : "ファイル設定",
-    "Show hidden files" : "隠しファイルを表示",
-    "Crop image previews" : "プレビュー画像を切り抜く",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "このアドレスを使用すれば、WebDAV経由でファイルにアクセスできます",
-    "Toggle %1$s sublist" : "サブリスト %1$s を切り替え",
     "Toggle grid view" : "グリッド表示の切り替え",
-    "No files in here" : "ファイルがありません",
-    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
-    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
-    "Select all" : "すべて選択",
-    "Upload too large" : "アップロードには大きすぎます。",
-    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
-    "No favorites yet" : "まだお気に入りはありません",
-    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
     "Deleted files" : "ゴミ箱",
     "Shares" : "共有",
     "Shared with others" : "他ユーザーと共有中",
     "Shared with you" : "他ユーザーがあなたと共有中",
-    "Shared by link" : "URLリンクで共有中",
     "Deleted shares" : "削除された共有",
     "Pending shares" : "保留中の共有",
-    "Text file" : "テキストファイル",
-    "New text file.txt" : "新規のテキストファイル作成",
-    "Select" : "選択",
-    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
-    "New" : "新規作成",
-    "Cannot transfer ownership of a file or folder you don't own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
-    "%s%% of %s used" : "%s%% 使用中、全体は%s",
-    "Settings" : "設定"
+    "This file has the tag {tag}" : "このファイルには {tag} タグがあります。",
+    "This file has the tags {firstTags} and {lastTag}" : "このファイルには {firstTags} と {lastTag} というタグがあります",
+    "Open folder {name}" : "フォルダ {name} を開く",
+    "ascending" : "昇順",
+    "descending" : "降順",
+    "Sort list by {column} ({direction})" : "{column} ({direction}) でリストを並べ替える",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
+    "Search for an account" : "アカウントを検索",
+    "Choose" : "選択",
+    "No files or folders have been deleted yet" : "まだ削除されたファイルやフォルダはありません"
 },
 "nplurals=1; plural=0;");
