@@ -38,7 +38,6 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} je promijenio vašu adresu e-pošte",
     "You changed your email address" : "Promijenili ste svoju adresu e-pošte",
     "Your email address was changed by an administrator" : "Administrator je promijenio vašu adresu e-pošte",
-    "You created app password \"{token}\"" : "Stvorili ste zaporku aplikacije „{token}”",
     "You deleted app password \"{token}\"" : "Izbrisali ste zaporku aplikacije „{token}”",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Preimenovali ste zaporku aplikacije „{token}” u „{newToken}”",
     "You granted filesystem access to app password \"{token}\"" : "Odobrili ste zaporki aplikacije „{token}” pristup datotečnom sustavu",
@@ -49,6 +48,7 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Udaljeno brisanje pokrenuto je %1$s",
     "Remote wipe has finished on %1$s" : "Udaljeno brisanje završilo je %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Izmijenjena je vaša <strong>zaporka</strong> ili <strong>adresa e-pošte</strong>",
+    "Apps" : "Aplikacije",
     "Wrong password" : "Pogrešna zaporka",
     "Saved" : "Spremljeno",
     "No user supplied" : "Nijedan korisnik nije podnesen",
@@ -58,12 +58,15 @@ OC.L10N.register(
     "installing and updating apps via the App Store or Federated Cloud Sharing" : "instaliranje i ažuriranje aplikacija putem trgovine aplikacijama ili dijeljenja putem udruženog oblaka",
     "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL upotrebljava zastarjelu inačicu %1$s (%2$s). Ažurirajte svoj operacijski sustav kako bi značajke, kao što je %3$s, pouzdano radile.",
+    "Administrator documentation" : "Dokumentacija za administratora",
+    "User documentation" : "Dokumentacija za korisnike",
     "Invalid SMTP password." : "Nevaljana zaporka za SMTP.",
     "Email setting test" : "Testiranje postavljanja e-pošte",
     "Well done, %s!" : "Odlično, %s!",
     "If you received this email, the email configuration seems to be correct." : "Ako ste primili ovu poruku e-pošte, čini se da je e-pošta pravilno konfigurirana.",
     "Email could not be sent. Check your mail server log" : "Slanje poruke e-pošte nije uspjelo. Provjerite zapis poslužitelja e-pošte",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Došlo je do problema pri slanju poruke e-pošte. Pregledajte svoje postavke. (Pogreška: %s)",
+    "Users" : "Korisnici",
     "Invalid user" : "Nevažeći korisnik",
     "Invalid mail address" : "Nevažeća adresa e-pošte",
     "Settings saved" : "Postavke spremljene",
@@ -95,7 +98,6 @@ OC.L10N.register(
     "Go to %s" : "Idi na %s",
     "Install Client" : "Instaliraj klijenta",
     "Logged in user must be a subadmin" : "Korisnik koji je prijavljen mora biti podadministrator",
-    "Apps" : "Aplikacije",
     "Settings" : "Postavke",
     "Personal" : "Osobno",
     "Administration" : "Administracija",
@@ -106,6 +108,7 @@ OC.L10N.register(
     "Basic settings" : "Osnovne postavke",
     "Sharing" : "Dijeljenje",
     "Availability" : "Raspoloživost",
+    "Calendar" : "Kalendar",
     "Personal info" : "Osobne informacije",
     "Mobile & desktop" : "Mobilni uređaji i osobna računala",
     "Email server" : "Poslužitelj e-pošte",
@@ -120,6 +123,7 @@ OC.L10N.register(
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Na čekanju je pozadinski zadatak za provjeravanje vjerodajnica SSL-a koje uvezu korisnici. Provjerite ponovno kasnije.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Prisutne su vjerodajnice SSL-a koje su uvezli korisnici i koje Nextcloud 21 ne upotrebljava. Mogu se uvesti putem naredbenog retka s pomoću naredbe „occ security:certificates:import”. U nastavku su prikazani njihovi putovi unutar podatkovnog direktorija.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Omogućen je stari format šifriranja na strani poslužitelja. Preporučujemo da ga onemogućite.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Omogućena je konfiguracija samo za čitanje. Time se sprječava postavljanje nekih konfiguracija putem web-sučelja. Nadalje, datoteku treba ručno prebaciti u način pisanja pri svakom ažuriranju.",
     "Nextcloud settings" : "Postavke Nextclouda",
     "Here you can decide which group can access certain sections of the administration settings." : "Ovdje možete odlučiti koja grupa može pristupiti određenim dijelovima administratorskih postavki.",
     "None" : "Nema",
@@ -147,7 +151,6 @@ OC.L10N.register(
     "View in store" : "Pogledajte u trgovini",
     "Visit website" : "Posjeti web-mjesto",
     "Report a bug" : "Prijavi pogrešku",
-    "User documentation" : "Dokumentacija za korisnike",
     "Admin documentation" : "Dokumentacija za administratore",
     "Developer documentation" : "Dokumentacija za razvojne programere",
     "This app is supported via your current Nextcloud subscription." : "Aplikacija je podržana unutar vaše trenutne pretplate na Nextcloud.",
@@ -155,10 +158,14 @@ OC.L10N.register(
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Istaknute aplikacije razvijaju članovi zajednice. One nude osnovnu funkcionalnost i spremne su za produkciju.",
     "Featured" : "Istaknuto",
     "Update to {update}" : "Ažuriraj na {update}",
+    "Icon" : "Ikona",
+    "Name" : "Naziv",
+    "Version" : "Inačica",
+    "Level" : "Razina",
+    "Actions" : "Radnje",
     "Results from other categories" : "Rezultati iz drugih kategorija",
     "No apps found for your version" : "Nije pronađena nijedna aplikacija za vašu inačicu",
     "Disable all" : "Onemogući sve",
-    "Enable all" : "Omogući sve",
     "_%n app has an update available_::_%n apps have an update available_" : ["Dostupno je ažuriranje za %n aplikaciju","Dostupno je ažuriranje za %n aplikacije","Dostupno je ažuriranje za %n aplikacija"],
     "Marked for remote wipe" : "Označeno za udaljeno brisanje",
     "Device settings" : "Postavke uređaja",
@@ -202,7 +209,7 @@ OC.L10N.register(
     "Copied!" : "Kopirano!",
     "Copy" : "Kopiraj",
     "Could not copy app password. Please copy it manually." : "Kopiranje zaporke aplikacije nije uspjelo. Kopirajte je ručno.",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Za izvršavanje navedenog postupka potrebno je proširenje PHP POSIX. Pogledajte {linkstart}dokumentaciju PHP-a{linkend} za više informacija.",
+    "Use system cron service to call the cron.php file every 5 minutes." : "Koristite se sistemskim servisom cron za pozivanje datoteke cron.php svakih 5 minuta.",
     "Profile" : "Profil",
     "Enable" : "Omogući",
     "Server-side encryption" : "Šifriranje na poslužitelju",
@@ -215,15 +222,14 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Ovo je posljednje upozorenje: želite li zaista omogućiti šifriranje?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Nije učitan modul za šifriranje, omogućite modul za šifriranje u izborniku aplikacije.",
     "Select default encryption module:" : "Odaberi zadani modul za šifriranje:",
+    "Cancel" : "Odustani",
+    "Confirm" : "Potvrdi",
+    "Submit" : "Šalji",
     "Remove group" : "Ukloni grupu",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Izbrisat ćete grupu {group}. Korisnici NEĆE biti izbrisani.",
-    "Please confirm the group removal " : "Potvrdite uklanjanje grupe ",
     "Current password" : "Trenutna zaporka",
     "New password" : "Nova zaporka",
     "Change password" : "Promijeni zaporku",
-    "png or jpg, max. 20 MB" : "png ili jpg, maks. 20 MB",
     "Picture provided by original account" : "Slika s izvornog računa",
-    "Cancel" : "Odustani",
     "Your biography" : "Vaša biografija",
     "Details" : "Pojedinosti",
     "You are a member of the following groups:" : "Član ste sljedećih grupa:",
@@ -235,7 +241,6 @@ OC.L10N.register(
     "Unset as primary email" : "Poništi primarnu adresu e-pošte",
     "This address is not confirmed" : "Ova adresa nije potvrđena",
     "Set as primary email" : "Postavi kao primarnu adresu e-pošte",
-    "Your email address" : "Vaša adresa e-pošte",
     "Additional email address {index}" : "Dodatne adrese e-pošte {index}",
     "Unable to delete primary email address" : "Nije moguće izbrisati primarnu adresu e-pošte",
     "Unable to update primary email address" : "Nije moguće ažurirati primarnu adresu e-pošte",
@@ -245,27 +250,37 @@ OC.L10N.register(
     "No email address set" : "Nije postavljena adresa e-pošte",
     "Additional emails" : "Dodatne adrese e-pošte",
     "Your headline" : "Vaš naslov",
-    "Language" : "Jezik",
     "Help translate" : "Pomozite prevesti",
     "Unable to update language" : "Nije moguće ažurirati jezik",
     "No language set" : "Nije postavljen jezik",
-    "Locale" : "Lokacija",
     "Your organisation" : "Vaša organizacija",
     "Your phone number" : "Vaš broj telefona",
     "Edit your Profile visibility" : "Uredite vidljivost profila",
     "Enable Profile" : "Omogući profil",
     "Unable to update profile enabled state" : "Nije moguće ažurirati stanje omogućenog profila",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Na profilu se primjenjuje stroža postavka vidljivosti ili opsega. Na primjer, ako je vidljivost postavljena na „Prikaži svima”, a opseg je postavljen na „Privatno”, primjenjuje se „Privatno”.",
-    "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "Nije moguće ažurirati vidljivost za {displayId}",
     "Your role" : "Vaša uloga",
     "Add" : "Dodaj",
+    "Default language" : "Zadani jezik",
+    "Common languages" : "Česti jezici",
+    "Other languages" : "Drugi jezici",
+    "Password change is disabled because the master key is disabled" : "Onemogućeno je mijenjanje zaporke jer je onemogućen glavni ključ",
+    "New user" : "Novi korisnik",
+    "Display name" : "Ime za prikaz",
+    "Email" : "E-pošta",
+    "Quota" : "Kvota",
+    "Language" : "Jezik",
+    "Avatar" : "Avatar",
+    "Group admin for" : "Administrator grupe za",
+    "User backend" : "Korisnički pozadinski sustav",
+    "Storage location" : "Mjesto pohrane",
+    "Last login" : "Posljednja prijava",
     "You do not have permissions to see the details of this user" : "Nemate dopuštenja za prikaz pojedinosti ovog korisnika",
-    "Add new password" : "Dodaj novu zaporku",
-    "Add new email address" : "Dodaj novu adresu e-pošte",
     "Add user to group" : "Dodaj korisnika u grupu",
     "Set user as admin for" : "Postavi korisnika kao administratora za",
     "Select user quota" : "Odaberi kvotu korisnika",
+    "{size} used" : "Iskorišteno {size}",
     "Delete user" : "Izbriši korisnika",
     "Wipe all devices" : "Izbriši podatke sa svih uređaja",
     "Disable user" : "Onemogući korisnika",
@@ -278,25 +293,14 @@ OC.L10N.register(
     "Account deletion" : "Brisanje računa",
     "Delete {userid}'s account" : "Izbriši račun koji pripada {userid}",
     "Welcome mail sent!" : "Poslana poruka dobrodošlice!",
-    "Edit User" : "Uredi korisnika",
     "Toggle user actions menu" : "Uklj./isklj. izbornik s radnjama korisnika",
-    "{size} used" : "Iskorišteno {size}",
-    "New user" : "Novi korisnik",
-    "Will be autogenerated" : "Automatski će se generirati",
-    "Display name" : "Ime za prikaz",
-    "Email" : "E-pošta",
-    "Default language" : "Zadani jezik",
-    "Add a new user" : "Dodaj novog korisnika",
-    "Group admin for" : "Administrator grupe za",
-    "Quota" : "Kvota",
-    "User backend" : "Korisnički pozadinski sustav",
-    "Storage location" : "Mjesto pohrane",
-    "Last login" : "Posljednja prijava",
-    "No users in here" : "Ovdje nema korisnika",
+    "Edit" : "Uredi",
+    "Show user backend" : "Prikaži korisnički pozadinski sustav",
+    "Show storage path" : "Prikaži put pohrane",
+    "Show last login" : "Prikaži posljednju prijavu",
+    "Send email" : "Pošalji poruku e-pošte",
     "Default quota" : "Zadana kvota",
-    "Common languages" : "Česti jezici",
-    "Other languages" : "Drugi jezici",
-    "Password change is disabled because the master key is disabled" : "Onemogućeno je mijenjanje zaporke jer je onemogućen glavni ključ",
+    "Select default quota" : "Odaberi zadanu kvotu",
     "Passwordless authentication requires a secure connection." : "Autentifikacija bez zaporke zahtijeva sigurnu vezu.",
     "Add WebAuthn device" : "Dodaj WebAuthn uređaj",
     "Please authorize your WebAuthn device." : "Autorizirajte svoj WebAuthn uređaj.",
@@ -311,26 +315,13 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "Sljedeći su uređaji konfigurirani za vaš račun:",
     "Your browser does not support WebAuthn." : "Vaš preglednik ne podržava WebAuthn.",
     "Your apps" : "Vaše aplikacije",
-    "Active apps" : "Aktivne aplikacije",
-    "Disabled apps" : "Onemogućene aplikacije",
-    "Updates" : "Ažuriranja",
-    "App bundles" : "Paketi aplikacija",
-    "Featured apps" : "Istaknute aplikacije",
     "{license}-licensed" : "Licencirano prema {license}",
     "Changelog" : "Zapis promjena",
     "by {author}\n{license}" : "{autor}\n{licenca}",
-    "Enter group name" : "Unesite naziv grupe",
-    "Add group" : "Dodaj grupu",
     "Active users" : "Aktivni korisnici",
     "Admins" : "Administratori",
     "Disabled users" : "Onemogućeni korisnici",
-    "Default quota:" : "Zadana kvota:",
-    "Select default quota" : "Odaberi zadanu kvotu",
-    "Show Languages" : "Prikaži jezike",
-    "Show last login" : "Prikaži posljednju prijavu",
-    "Show user backend" : "Prikaži korisnički pozadinski sustav",
-    "Show storage path" : "Prikaži put pohrane",
-    "Send email to new user" : "Pošalji poruku e-pošte novom korisniku",
+    "Group name" : "Naziv grupe",
     "Not saved" : "Nije spremljeno",
     "Sending…" : "Slanje…",
     "Email sent" : "E-pošta je poslana",
@@ -346,41 +337,42 @@ OC.L10N.register(
     "Twitter" : "Twitter",
     "Website" : "Web-mjesto",
     "Profile visibility" : "Vidljivost profila",
+    "Locale" : "Lokacija",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Nije dostupno jer je ovo svojstvo potrebno za osnovnu funkcionalnost, uključujući dijeljenje datoteka i pozivnice za kalendar",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nije dostupno jer nije dopušteno objavljivanje korisničkih podataka na poslužitelju pretraživanja, obratite se administratoru sustava ako imate pitanja",
+    "Active apps" : "Aktivne aplikacije",
+    "Disabled apps" : "Onemogućene aplikacije",
+    "Updates" : "Ažuriranja",
+    "App bundles" : "Paketi aplikacija",
+    "Featured apps" : "Istaknute aplikacije",
     "Show to everyone" : "Prikaži svima",
     "Show to logged in users only" : "Prikaži samo prijavljenim korisnicima",
     "Hide" : "Sakrij",
     "Download and enable" : "Preuzmi i omogući",
-    "Enable untested app" : "Omogući neprovjerenu aplikaciju",
     "The app will be downloaded from the App Store" : "Aplikacija će se preuzeti iz trgovine aplikacijama",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ova aplikacija nije označena kao kompatibilna s vašom inačicom Nextclouda. Ako odlučite nastaviti, moći ćete instalirati aplikaciju. Imajte na umu da aplikacija možda neće raditi kako očekujete.",
     "Never" : "Nikad",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacija je omogućena, ali je treba ažurirati. Za 5 sekundi bit ćete preusmjereni na stranicu za ažuriranje.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Pogreška: ova aplikacija ne može biti omogućena jer čini poslužitelj nestabilnim",
-    "Administrator documentation" : "Dokumentacija za administratora",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zaprimljeno je previše zahtjeva iz vaše mreže. Pokušajte kasnije ili se obratite administratoru ako se radi o pogrešci.",
     "Documentation" : "Dokumentacija",
     "Forum" : "Forum",
     "Login" : "Prijava",
-    "Plain" : "Čisti tekst",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "SSL" : "SSL",
     "Open documentation" : "Otvori dokumentaciju",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Važno je postaviti ovaj poslužitelj kako biste mogli slati poruke e-pošte u vezi s resetiranjem zaporke i obavijesti.",
     "Send mode" : "Način slanja",
     "Encryption" : "Šifriranje",
     "Sendmail mode" : "Način slanja pošte",
     "From address" : "Adresa pošiljatelja",
-    "Authentication method" : "Način autentifikacije",
-    "Authentication required" : "Potrebna autentifikacija",
     "Server address" : "Adresa poslužitelja",
     "Port" : "Port",
+    "Authentication" : "Autentifikacija",
+    "Authentication required" : "Potrebna autentifikacija",
     "Credentials" : "Vjerodajnice",
     "SMTP Username" : "Korisničko ime za SMTP",
     "SMTP Password" : "SMTP zaporka",
     "Save" : "Spremi",
-    "Send email" : "Pošalji poruku e-pošte",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pravilna konfiguracija iznimno je važna za sigurnost i performanse vaše instance. Kako bismo vam pomogli pravilno konfigurirati sustav, provest ćemo neke automatske provjere. Za više informacija pogledajte navedenu dokumentaciju.",
     "All checks passed." : "Sve su provjere uspješno dovršene.",
     "There are some errors regarding your setup." : "Postoje neke pogreške u vezi s vašim postavom.",
@@ -388,7 +380,6 @@ OC.L10N.register(
     "Checking for system and security issues." : "Provjera sustava i sigurnosnih postavki.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Pažljivo pročitajte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">upute za instalaciju ↗</a> i potražite postoje li ikakve pogreške ili upozorenja u <a href=\"%2$s\">zapisima</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Provjerite sigurnost svojeg Nextclouda s pomoću <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">sigurnosnog skeniranja ↗</a>.",
-    "Version" : "Inačica",
     "You need to enable the File sharing App." : "Morate omogućiti aplikaciju za dijeljenje datoteka.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administrator možete detaljnije podešavati dijeljenja. Pogledajte odgovarajuću dokumentaciju za više informacija.",
     "Allow apps to use the Share API" : "Dopusti aplikacijama korištenje API-ja za dijeljenje",
@@ -408,8 +399,6 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "Ograniči korisnike na dijeljenje samo s korisnicima unutar svoje grupe",
     "Exclude groups from sharing" : "Izuzmi grupe iz dijeljenja",
     "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene sadržaje, ali ih neće moći pokrenuti.",
-    "Allow username autocompletion in share dialog" : "Dopusti automatsko dovršavanje korisničkog imena u dijaloškom okviru za dijeljenje",
-    "Allow username autocompletion to users within the same groups" : "Dopusti automatsko dovršavanje korisničkog imena na korisnike iz istih grupa",
     "Allow username autocompletion to users based on phone number integration" : "Omogući korisnicima automatsko dovršavanje korisničkog imena na temelju integracije telefonskog broja",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ako je omogućeno automatsko dovršavanje „ista grupa” i „integracija telefonskog broja”, bilo koje od tih podudaranja dovoljno je za prikaz korisnika.",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Prikaži tekst izjave o odricanju od odgovornosti na stranici za otpremanje javnih poveznica (prikazuje se samo kad je popis datoteka skriven)",
@@ -425,67 +414,31 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ovo izdanje Nextclouda nije podržano i nisu dostupne trenutne obavijesti.",
     "Use a second factor besides your password to increase security for your account." : "Koristite se i drugim faktorom pored zaporke kako biste povećali sigurnost svog računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ako se za povezivanje s Nextcloudom koristite aplikacijama treće strane, stvorite i konfigurirajte lozinku za svaku aplikaciju prije omogućavanja drugog faktora za provođenje autentifikacije.",
-    "Migration in progress. Please wait until the migration is finished" : "Migracije u tijeku. Pričekajte da migracija završi",
-    "Migration started …" : "Migracija je pokrenuta…",
-    "An error occurred while changing your language. Please reload the page and try again." : "Došlo je do pogreške pri promijeni jezika. Ponovo učitajte stranicu i pokušajte ponovo.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Došlo je do pogreške pri promijeni postavke lokacije. Ponovo učitajte stranicu i pokušajte ponovo.",
-    "Select a profile picture" : "Odaberite profilnu sliku",
-    "Week starts on {fdow}" : "Tjedan počinje {fdow}",
-    "Couldn't remove app." : "Nije moguće ukloniti aplikaciju.",
-    "Couldn't update app." : "Neuspješno ažuriranje aplikacije.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Pozadinski sustav ne podržava promjenu zaporke, ali je ažuriran korisnikov ključ za šifriranje.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Nismo mogli utvrditi je li inačica TLS-a cURL-a zastarjela jer je došlo do pogreške tijekom slanja HTTPS zahtjeva na https://nextcloud.com. Više informacija potražite u Nextcloudovoj datoteci sa zapisima.",
-    "You need to set your user email before being able to send test emails." : "Prije slanja testnih poruka e-pošte trebate postaviti svoj korisnički račun e-pošte.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Opozivanje ovog tokena može spriječiti brisanje sadržaja s vašeg uređaja ako brisanje nije pokrenuto.",
-    "Set as primary mail" : "Postavi kao primarnu adresu e-pošte",
-    "Change privacy level of email" : "Promijeni razinu privatnosti e-pošte",
-    "All languages" : "Svi jezici",
-    "Everyone" : "Svi",
-    "An error occured during the request. Unable to proceed." : "Došlo je do pogreške tijekom rješavanja zahtjeva. Nije moguće nastaviti.",
-    "Test email settings" : "Ispitaj postavke e-pošte",
-    "Please read carefully before activating server-side encryption: " : "Pažljivo pročitajte sljedeće prije aktiviranja šifriranja na poslužitelju: ",
-    "Enable encryption" : "Omogući šifriranje",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Morate prenijeti svoje ključeve za šifriranje sa stare inačice modula za šifriranje (ownCloud <= 8.0) na novu. Omogućite „zadani modul za šifriranje” i pokrenite 'occ encryption:migrate'.",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Morate prenijeti svoje ključeve za šifriranje sa stare inačice modula za šifriranje (ownCloud <= 8.0) na novu.",
-    "Start migration" : "Pokreni prijenos",
-    "Last job execution ran %s. Something seems wrong." : "Posljednji zadatak izvršen je %s. Čini se da nešto nije u redu.",
-    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Određeni zadaci nisu izvršeni od %s. Razmislite o povećanju učestalosti izvršenja.",
-    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Određeni zadaci nisu izvršeni od %s. Razmislite o prebacivanju na sistemski cron.",
-    "Last job ran %s." : "Posljednji zadatak pokrenut je %s.",
-    "Background job didn’t run yet!" : "Pozadinski zadatak još nije pokrenut!",
-    "Pick background job setting" : "Odaberite postavku pozadinskog zadatka",
-    "Recommended" : "Preporuceno",
-    "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php treba izvršiti korisnik „%s”.",
-    "days" : "dana",
-    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Dopusti automatsko dovršavanje korisničkog imena prilikom unosa imena i prezimena ili adrese e-pošte (zanemarujući nedostatak podudaranja s podacima u imeniku i istoj grupi)",
-    "Change privacy level of profile picture" : "Promijeni razinu privatnosti profilne slike",
-    "Upload new" : "Otpremi novu",
-    "Select from Files" : "Odaberi iz datoteka",
-    "Remove image" : "Ukloni sliku",
-    "Choose as profile picture" : "Odaberi kao profilnu sliku",
-    "You are using <strong>%s</strong>" : "Koristite <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Koristite <strong>%1$s</strong> od <strong>%2$s</strong> (<strong>%3$s% %</strong>)",
-    "Change privacy level of full name" : "Promijeni razinu privatnosti punog imena",
-    "No display name set" : "Nije postavljeno ime za prikaz",
-    "Change privacy level of phone number" : "Promijeni razinu privatnosti broja telefona",
-    "Address" : "Adresa",
-    "Change privacy level of address" : "Promijeni razinu privatnosti adrese",
-    "Your postal address" : "Vaša poštanska adresa",
-    "Change privacy level of website" : "Promijeni razinu privatnosti web-mjesta",
-    "It can take up to 24 hours before the account is displayed as verified." : "Potvrđivanje računa može potrajati i do 24 sata.",
-    "Link https://…" : "Poveznica https://...",
-    "Change privacy level of Twitter profile" : "Promijeni razinu privatnosti Twitter profila",
-    "Twitter handle @…" : "Twitter ime @…",
-    "Admin privileges" : "Administratorske ovlasti",
-    "Unable to update biography" : "Nije moguće ažurirati biografiju",
-    "Unable to update full name" : "Nije moguće ažurirati ime i prezime",
-    "No full name set" : "Nije postavljeno ime i prezime",
-    "Unable to update headline" : "Nije moguće ažurirati naslov",
-    "Unable to update organisation" : "Nije moguće ažurirati organizaciju",
-    "Unable to update role" : "Nije moguće ažurirati ulogu",
-    "Change scope level of {accountProperty}" : "Promijeni razinu opsega za {accountProperty}",
-    "Unable to update federation scope of the primary {accountProperty}" : "Nije moguće ažurirati opseg udruženja primarnog {accountProperty}",
-    "Unable to update federation scope of additional {accountProperty}" : "Nije moguće ažurirati opseg udruženja dodatnog {accountProperty}",
-    "Avatar" : "Avatar"
+    "You created app password \"{token}\"" : "Stvorili ste zaporku aplikacije „{token}”",
+    "Enable all" : "Omogući sve",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Za izvršavanje navedenog postupka potrebno je proširenje PHP POSIX. Pogledajte {linkstart}dokumentaciju PHP-a{linkend} za više informacija.",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Izbrisat ćete grupu {group}. Korisnici NEĆE biti izbrisani.",
+    "Please confirm the group removal " : "Potvrdite uklanjanje grupe ",
+    "png or jpg, max. 20 MB" : "png ili jpg, maks. 20 MB",
+    "Your email address" : "Vaša adresa e-pošte",
+    "Add new password" : "Dodaj novu zaporku",
+    "Add new email address" : "Dodaj novu adresu e-pošte",
+    "Edit User" : "Uredi korisnika",
+    "Will be autogenerated" : "Automatski će se generirati",
+    "Add a new user" : "Dodaj novog korisnika",
+    "No users in here" : "Ovdje nema korisnika",
+    "Enter group name" : "Unesite naziv grupe",
+    "Add group" : "Dodaj grupu",
+    "Default quota:" : "Zadana kvota:",
+    "Show Languages" : "Prikaži jezike",
+    "Send email to new user" : "Pošalji poruku e-pošte novom korisniku",
+    "Enable untested app" : "Omogući neprovjerenu aplikaciju",
+    "Plain" : "Čisti tekst",
+    "NT LAN Manager" : "NT LAN Manager",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Authentication method" : "Način autentifikacije",
+    "Allow username autocompletion in share dialog" : "Dopusti automatsko dovršavanje korisničkog imena u dijaloškom okviru za dijeljenje",
+    "Allow username autocompletion to users within the same groups" : "Dopusti automatsko dovršavanje korisničkog imena na korisnike iz istih grupa"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
