@@ -1,10 +1,10 @@
 OC.L10N.register(
     "core",
     {
-    "Please select a file." : "請選擇檔案。",
+    "Please select a file." : "請選擇一個檔案。",
     "File is too big" : "檔案太大",
-    "The selected file is not an image." : "選擇的檔案不是圖像檔案。",
-    "The selected file cannot be read." : "選擇的檔案無法讀取。",
+    "The selected file is not an image." : "已選的檔案不是圖像檔案。",
+    "The selected file cannot be read." : "無法讀取已選的檔案。",
     "The file was uploaded" : "檔案已上傳",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 參數的設定",
@@ -19,35 +19,46 @@ OC.L10N.register(
     "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
     "Invalid image" : "圖像無效",
     "No temporary profile picture available, try again" : "沒有可用的臨時個人資料圖片，請再試一次",
-    "No crop data provided" : "未設定剪裁",
+    "No crop data provided" : "未提供剪裁數據",
     "No valid crop data provided" : "未提供有效的剪裁設定",
     "Crop is not square" : "剪裁設定不是正方形",
     "State token does not match" : "狀態權杖不相符",
     "Invalid app password" : "無效的應用程式密碼",
     "Could not complete login" : "無法完成登錄",
+    "State token missing" : "找不到狀態權杖",
     "Your login token is invalid or has expired" : "您的登入權杖無效或已過期",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "不支援 Nextcloud 的這個社群版本，且推播通知有所限制。",
     "Login" : "登入",
+    "Please try again" : "請再試一次",
     "Password reset is disabled" : "密碼重設已停用",
     "Could not reset password because the token is expired" : "權杖已過期，無法重設密碼",
     "Could not reset password because the token is invalid" : "重設密碼權杖無效，重設失敗",
+    "Password is too long. Maximum allowed length is 469 characters." : "密碼太長。 允許的最大長度為 469 個字元。",
     "%s password reset" : "%s 密碼重設",
     "Password reset" : "密碼重設",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的按鈕來重設您的密碼。若您沒有要求重設密碼，請不用理會此電子郵件。",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "點取下方的連結以重設您的密碼。如果您沒有要求重設密碼的話，請不用理會此電子郵件。",
     "Reset your password" : "重設密碼",
+    "Requested task type does not exist" : "請求的任務類型不存在",
+    "Necessary language model provider is not available" : "沒有必要的語言模型提供者",
+    "Task not found" : "找不到任務",
+    "Internal error" : "內部錯誤",
+    "No translation provider available" : "沒有可用翻譯提供者",
+    "Could not detect language" : "無法檢測語言",
+    "Unable to translate" : "無法翻譯",
     "Nextcloud Server" : "Nextcloud 伺服器",
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
     "The user limit of this instance is reached." : "的達此實例的用戶上限。",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加用戶限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
     "Learn more ↗" : "了解更多",
     "Preparing update" : "正在準備更新",
-    "[%d / %d]: %s" : "[%d / %d]： %s",
+    "[%d / %d]: %s" : "[%d / %d]：%s",
     "Repair step:" : "修復步驟：",
     "Repair info:" : "修復資訊：",
     "Repair warning:" : "修復警告：",
     "Repair error:" : "修復錯誤：",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "由於自動更新功能已在 config.php 檔案中設定停用，請使用命令列（command line）更新系統。",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "由於更新功能已在 config.php 中設定停用，請使用命令列（command line）更新系統。",
     "Turned on maintenance mode" : "啟用維護模式",
     "Turned off maintenance mode" : "停用維護模式",
     "Maintenance mode is kept active" : "伺服器正處於維護模式",
@@ -73,24 +84,22 @@ OC.L10N.register(
     "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "您尚未設置或驗證您的電郵伺服器配置。請前往 {mailSettingsStart} 基本設置 {mailSettingsEnd} 進行設置。然後使用表單下方的【發送電郵】按鈕驗證您的設置。",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "您的數據庫並未使用 \"READ COMMITTED\" 的交易隔離等級。當有多個操作平行進行時，這可能會造成問題。",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "未偵測到 PHP 模組 'fileinfo'。強烈建議啟用這個模組，以取得最好的 MIME 檔案類型偵測支援。",
+    "Your remote address was identified as \"{remoteAddress}\" and is bruteforce throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的遠端地址被識別為「{remoteAddress}」，且目前正受到強力限制，導致降低了各種請求的效能。若遠端地址不是您的地址，可能代表代理伺服器設定不正確。可以在{linkstart}文件 ↗{linkend}中找到進一步的資訊。",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "交易性檔案上鎖已停用，這可能導致爭用條件問題。在config.php中啟用 “filelocking.enabled” 可以避免這些問題。有關更多信息，請參見{linkstart}文檔↗{linkend}。",
+    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "數據庫用於事務檔案鎖定。為提高性能，請配置 memcache（如果可用）。有關詳細信息，請參閱{linkstart}說明書 ↗{linkend}。",
     "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "請確保將 config.php 文件中的“overwrite.cli.url”選項設置為您的用戶主要用於訪問此 Nextcloud 的 URL。建議：“{suggestedOverwriteCliURL}”。否則，通過 cron 生成的 URL 可能會出現問題。（但是，建議的 URL 可能不是您的用戶主要用於訪問此 Nextcloud 的 URL。最好是仔細檢查以防萬一。）",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "你並未設置手機國際冠碼。設置後用戶在個人檔案設定手機號碼時不必再輸入國際冠碼。若要這樣做，請新增「default_phone_region」於設定檔，允許的國家及地區請參閱 {linkstart}ISO 3166-1 code ↗{linkend} 清單。",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : " 無法透過 CLI 來執行排程工作，發生以下技術性錯誤：",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "最後一次後台作業執行了{relativeTime}。似乎有問題。{linkstart}檢查後台作業設置↗{linkend}。",
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被限制，以避免我們的免費服務負載過重。請至 {linkstart}nextcloud.com/enterprise{linkend} 取得更多關於 Nextcloud 企業版的資訊。",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "此伺服器沒有可用的互聯網連接（無法訪問多個端點）。 這意味著某些功能（例如掛載外部存儲、有關更新或安裝第三方應用程式的通知）將無法使用。 遠端存取檔案和發送通知電子郵件也可能不起作用。 請建立從此伺服器到互聯網的連接以享受所有功能。",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "尚未配置內存緩存。為了提高性能，請配置內存緩存（如有）。可以在 {linkstart}說明書↗{linkend} 中找到更多資訊。",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "由於安全原因，強烈建議不要使用PHP找到適合隨機性的來源。可以在{linkstart}文檔↗{linkend}中找到更多信息。",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "您當前正在運行PHP {version}。只要您的發行版支持，請升級PHP版本以利用 {linkstart}PHP Group↗提供的性能和安全更新{linkend}。",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 是支援 PHP 7.3 的最後版本，Nextcloud 24 僅支援 PHP 7.4 以上的版本。",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "反向代理標頭（reverse proxy header）配置不正確，或者您正在從受信任的代理（trusted proxy）存取 Nextcloud。如果不是這樣，則這是一個安全問題，並且可以使攻擊者欺騙其對 Nextcloud 可見的IP地址。可以在{linkstart}文檔↗{linkend}中找到更多資訊。",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached 配置為分布式緩存，但是安裝了錯誤的PHP模塊 “memcache”。\\OC\\Memcache\\Memcached 僅支持 “memcached”，不支持 “memcache”。有關這兩個模塊的信息，請參見{linkstart}內存緩存wiki {linkend}。",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "某些檔案未通過完整性檢查。有關如何解決此問題的更多信息，請參見{linkstart1}文檔↗{linkend}。（{linkstart2}無效檔案清單…{linkend} / {linkstart3}重新掃描…{linkend}）",
     "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache 模塊配置不正確。 請參閱 {linkstart} 文檔 ↗{linkend} 了解更多信息。",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "無法取得 PHP 中的 \"set_time_limit\" 函式。這可能導致執行過程被終止並造成不完整安裝。我們強烈建議啟用該函式。",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "您的 PHP 並未啟用 FreeType 支援，導致大頭貼產生器和設定界面無法使用。",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "在資料表 \"{tableName}\" 中，找不到索引值 \"{indexName}\" 。",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "在數據庫表 \"{tableName}\" 中，找不到索引值 \"{indexName}\"。",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "數據庫缺少某些索引值。由於將索引添加到大型數據庫表可能需要一段時間，安裝程序因此不會自動添加索引。您可執行 “occ db:add-missing-indices” 來手動新增那些缺少的索引值。當索引值新增完成後，查詢的速度通常會變得快許多",
     "Missing primary key on table \"{tableName}\"." : "數據表 \"{tableName}\" 缺少主鍵。",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "數據庫缺少一些主鍵。由於在大表上添加主鍵可能會花費一些時間，因此我們不會自動添加主鍵。通過運行 “occ db:add-missing-primary-keys”，可以在實例繼續運行的同時手動添加那些缺少的主鍵。",
@@ -99,8 +108,9 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "您的 Nextcloud 缺少了某些建議的 PHP 模組。為了提升效能與相容性，強烈建議您安裝這些 PHP 模組。",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "雖然已啟用佈景主題應用程式，但並未啟用 PHP 模組「imagick」。為了讓 favicon 產生流程正常運作，您必須安裝並啟用此模組。",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "未啟用 PHP 模組「gmp」與「bcmath」。若您要使用 WebAuthn 免密碼驗證，這些模組就是必要的。",
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "您好像正在運行 32 位 PHP 版本。Nextcloud 需要 64 位才能運行良好。請將您的操作系統和 PHP 升級到 64 位！有關更多詳細信息，請閱讀 {linkstart} 有關的說明書頁面 ↗{linkend}。",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "本系統安裝的 php-imagick 不支援 SVG，為了更好的相容性，建議安裝它。",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "數據庫中的某些列缺少對 big int 的轉換。由於更改大表上的列類型可能需要一些時間，因此無法自動更改它們。通過運行 “occ db：convert-filecache-bigint”，可以手動應用這些未決的更改。實例處於脫機狀態時需要執行此操作。有關更多詳細信息，請{linklink}關於此↗{linkend}的文檔頁面。",
+    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "資料庫的有些欄位缺少 big int 格式轉換。因為欄位格式轉換需要一些時間，所以沒有自動轉換。您可以執行 \"occ db:convert-filecache-bigint\" 手動完成轉換，轉換時 Nextcloud 服務必須處於離線狀態。詳情請參閱{linkstart}關於這個問題的文件頁面 ↗{linkend}。",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "目前您的後端數據庫使用 SQLite，在大型服務當中，我們建議您使用其他的數據庫後端。",
     "This is particularly recommended when using the desktop client for file synchronisation." : "若您使用電腦客戶端來同步檔案，非常建議您這麼做。",
     "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "要遷移到另一個數據庫，請使用指令工具：“ occ db：convert-type”，或參閱 {linkstart} 說明書↗{linkend}。",
@@ -110,6 +120,7 @@ OC.L10N.register(
     "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "此站台使用Amazon S3物件儲存為主要儲存區。上傳檔案會暫存在伺服器，因此建議PHP的暫存資料夾最少要有50GB可用容量。請在登入檔中查閱關於資料夾路徑及可用容量的詳細資訊。要增進效能，請在php.ini中變更暫存資料夾位置，或將該資料夾容量增加。",
     "The temporary directory of this instance points to an either non-existing or non-writable directory." : "此實例的臨時目錄指向一個不存在或不可寫的目錄。",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "您正在通過安全連接存取實例，但是您的實例正在生成不安全的URL。這很可能意味著您被隱藏在反向代理（reverse proxy）之後，並且覆蓋配置變量（overwrite config variables）未正確設置。請閱讀{linkstart}有關此的文檔頁面↗{linkend}。",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "此實例以除錯模式執行。僅在近端開發且非生產環境時才啟用這個。",
     "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
     "For more details see the {linkstart}documentation ↗{linkend}." : "有關更多細節，請參見 {linkstart} 說明書↗{linkedin}。",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取。這表示 .htaccess 設定檔並未生效。我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
@@ -118,7 +129,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不包防 \"{expected}\" ，這是一個潛在的安全性和隱私風險，建議調整此項設定。",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP header “{header}” 未設置為 “ {val1}”、“ {val2}”、“{val3}”、“{val4}” 或 “{val5}”。這可能會洩漏引用資訊。請參閱 {linkstart}W3C建議↗{linkend}。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "未將 “Strict-Transport-Security” HTTP header 設置為至少“{seconds}”秒。為了增強安全性，建議按照{linkstart}安全提示↗{linkend}中的說明啟用 HSTS。",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "通過HTTP不安全地存取站點。強烈建議您將伺服器設置改為要求HTTPS，如{linkstart}安全提示↗{linkend}中所述。",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "透過 HTTP 不安全地訪問網站。強烈建議您將伺服器設置為需要 HTTPS，如{linkstart}安全提示 ↗{linkend} 中所述。如果不這樣做，一些重要的網站功能，如「複製到剪貼板」或「服務工作者」將無法使用！。",
     "unknown text" : "文字不詳",
     "Hello world!" : "哈囉，世界！",
     "sunny" : "晴朗的",
@@ -131,10 +142,11 @@ OC.L10N.register(
     "Update to {version}" : "更新到 {version}",
     "An error occurred." : "發生錯誤。",
     "Please reload the page." : "請重新整理頁面。",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗，檢視<a href=\"{url}\">論壇上的文章</a>來瞭解更多。",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">請查看我們關於此問題的論壇帖子</a>來瞭解更多。",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>舉報此問題。",
     "Continue to {productName}" : "前往 {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
+    "Applications menu" : "應用程式選項單",
     "More apps" : "更多應用程式",
     "Currently open" : "目前開啟",
     "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
@@ -144,12 +156,13 @@ OC.L10N.register(
     "Please contact your administrator." : "請聯絡系統管理員。",
     "An internal error occurred." : "發生內部錯誤",
     "Please try again or contact your administrator." : "請重試或聯絡系統管理員",
-    "Log in to {productName}" : "登入至 {productName}",
     "Account name or email" : "賬戶名稱或電郵地址",
     "Password" : "密碼",
+    "Log in to {productName}" : "登入至 {productName}",
     "Wrong username or password." : "錯誤的用戶名稱 或 密碼",
     "User disabled" : "用戶已遭停用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效，下一次登入將會被延時 30 秒。",
+    "Log in with a device" : "使用免密碼裝置登入",
     "Username or email" : "用戶名稱 或 電郵地址",
     "Your account is not setup for passwordless login." : "你的賬號尚未設定免密碼登入。",
     "Browser not supported" : "不支持該瀏覽器",
@@ -157,8 +170,7 @@ OC.L10N.register(
     "Your connection is not secure" : "您的連線不安全",
     "Passwordless authentication is only available over a secure connection." : "無密碼身分驗證僅支援經加密的連線。",
     "Reset password" : "重設密碼",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
-    "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "如果此賬戶存在，密碼重置郵件已發送到其電郵地址。如果您沒有收到，請驗證您的電郵地址和/或賬戶名，檢查您的垃圾郵件/垃圾資料夾或向您當地的管理員協助。",
     "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼電郵。請聯絡您的管理員。",
     "Password cannot be changed. Please contact your administrator." : "無法重設密碼，請聯絡管理員。",
     "Back to login" : "回到登入畫面",
@@ -180,8 +192,17 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機 apps 之中。",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基於 Collabora Online 構建的協作文件、試算表和演講文稿。",
+    "Distraction free note taking app." : "無干擾的筆記應用程式。",
+    "Search contacts" : "搜尋聯絡人",
+    "Search contacts …" : "搜尋聯絡人…",
+    "Could not load your contacts" : "無法載入您的聯絡人",
+    "No contacts found" : "查無聯絡人",
+    "Show all contacts …" : "顯示所有聯絡人…",
+    "Install the Contacts app" : "安裝「通訊錄」應用程式",
+    "Loading your contacts …" : "正在載入聯絡人…",
+    "Looking for {term} …" : "正在搜尋 {term} …",
     "Forgot password?" : "忘記密碼？",
-    "Log in with a device" : "使用免密碼裝置登入",
+    "Back to login form" : "回到登入表格",
     "Back" : "返回",
     "Login form is disabled." : "登入表格已停用",
     "Edit Profile" : "編輯個人設定",
@@ -189,44 +210,34 @@ OC.L10N.register(
     "You have not added any info yet" : "您尚未新增任何資訊",
     "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
     "Error opening the user status modal, try hard refreshing the page" : "打開用戶狀態模式時出錯，請嘗試刷新頁面",
-    "Search starts once you start typing" : "開始輸入後開始搜尋",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "一旦您開始輸入，搜尋就會開始，您可以使用方向鍵到達結果",
     "Reset search" : "重置搜尋",
     "Start search" : "開始搜尋",
     "Search for {name} only" : "只搜尋 {name}",
-    "No results for {query}" : "{query} 查詢沒有結果",
-    "Press enter to start searching" : "按 Enter 開始搜尋",
     "Start typing to search" : "輸入文字以檢索",
     "Loading more results …" : "正在載入更多結果...",
     "Load more results" : "載入更多結果",
     "Search" : "搜尋",
+    "No results for {query}" : "{query} 查詢沒有結果",
+    "Press Enter to start searching" : "按 Enter 開始搜尋",
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
+    "This browser is not supported" : "不支援此瀏覽器",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
+    "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
+    "Supported versions" : "支援的版本",
+    "{name} version {version} and above" : "{name} 的版本 {version} 及更新",
+    "Settings menu" : "設定選單",
+    "Avatar of {displayName}" : "{displayName} 的虛擬化身",
     "Search {types} …" : "搜尋 {types} 中 …",
-    "Settings" : "設定",
-    "Could not load your contacts" : "無法載入您的聯絡人",
-    "Search contacts …" : "搜尋聯絡人…",
-    "No contacts found" : "查無聯絡人",
-    "Show all contacts …" : "顯示所有聯絡人…",
-    "Install the Contacts app" : "安裝「通訊錄」應用程式",
-    "Loading your contacts …" : "正在載入聯絡人…",
-    "Looking for {term} …" : "正在搜尋 {term} …",
     "No" : "否",
     "Yes" : "是",
-    "No files in here" : "此處沒有任何檔案",
-    "New folder" : "新資料夾",
-    "No more subfolders in here" : "沒有子資料夾",
-    "Name" : "名稱",
-    "Size" : "大小",
-    "Modified" : "已修改",
-    "\"{name}\" is an invalid file name." : "\"{name}\" 是無效的檔案名稱。",
-    "File name cannot be empty." : "檔案名稱不能為空。",
-    "\"/\" is not allowed inside a file name." : "不允許檔案名稱中出現 \"/\"。",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
-    "{newName} already exists" : "{newName} 已經存在",
+    "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
+    "Copy to {target}" : "複製到 {target}",
     "Copy" : "複製",
+    "Move to {target}" : "移動到 {target}",
     "Move" : "移動",
-    "Error loading file picker template: {error}" : "載入檔案選擇器模板時出錯： {error}",
     "OK" : "OK",
     "Error loading message template: {error}" : "載入訊息模板時出錯： {error}",
     "read-only" : "唯讀",
@@ -235,22 +246,13 @@ OC.L10N.register(
     "New Files" : "新檔案",
     "Already existing files" : "已經存在的檔案",
     "Which files do you want to keep?" : "您要保留哪一個檔案？",
-    "If you select both versions, the copied file will have a number added to its name." : "如果您同時選擇兩個版本，被複製的那個檔案名稱後面會加上編號",
+    "If you select both versions, the copied file will have a number added to its name." : "如果您同時選擇兩個版本，複製的那個檔案名稱後面會加上編號。",
     "Cancel" : "取消",
     "Continue" : "繼續",
     "(all selected)" : "（已全選）",
     "({count} selected)" : "（已選擇 {count} 項）",
-    "Error loading file exists template" : "載入「已存在檔案」的模板時發生錯誤",
-    "Show list view" : "顯示清單視圖",
-    "Show grid view" : "顯示網格視圖",
-    "Pending" : "待辦中",
-    "Copy to {folder}" : "複製到 {folder}",
-    "Move to {folder}" : "移動到 {folder}",
+    "Error loading file exists template" : "載入已存在的模板時發生錯誤",
     "Saving …" : "儲存中 ...",
-    "Authentication required" : "必須驗證",
-    "This action requires you to confirm your password" : "此操作需要您再次確認密碼",
-    "Confirm" : "確認",
-    "Failed to authenticate, try again" : "驗證失敗，請再試一次",
     "seconds ago" : "幾秒前",
     "Connection to server lost" : "伺服器連線中斷",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時出錯，%n 秒後重新整理"],
@@ -272,6 +274,7 @@ OC.L10N.register(
     "Strong password" : "密碼強度極佳",
     "No action available" : "沒有可用的操作",
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
+    "Close \"{dialogTitle}\" dialog" : "關閉 \"{dialogTitle}\" 對話",
     "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
     "Restricted" : "受限",
     "Invisible" : "隱藏",
@@ -289,6 +292,7 @@ OC.L10N.register(
     "The profile does not exist." : "個人資料不存在",
     "Back to %s" : "回到 %s",
     "Page not found" : "沒有找到頁面",
+    "The page could not be found on the server or you may not be allowed to view it." : "在伺服器上找不到該頁面，或者您可能無法查看它。",
     "Too many requests" : "太多要求",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自你的網路，請稍後再試，若你認為這不該發生，請回報系統管理員這項錯誤。",
     "Error" : "錯誤",
@@ -325,7 +329,7 @@ OC.L10N.register(
     "Database tablespace" : "數據庫資料表空間",
     "Database host" : "數據庫主機",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
-    "Performance warning" : "效能警告",
+    "Performance warning" : "性能警告",
     "You chose SQLite as database." : "您選擇了 SQLite 作為數據庫",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或是開發用站台，針對上線服務我們建議使用其他數據庫後端。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若使用桌面版或是手機版客戶端同步檔案，不建議使用 SQLite",
@@ -338,12 +342,11 @@ OC.L10N.register(
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "這個應用程式需要啟用 Javascript 才能正常運作，請{linkstart}啟用Javascript{linkend}然後重新整理頁面。",
     "Skip to main content" : "跳到主內容",
     "Skip to navigation of app" : "跳到應用程式導覽",
+    "Go to %s" : "前往 %s",
     "Get your own free account" : "取得免費賬號",
-    "%s's homepage" : "%s 的主頁",
-    "Contacts" : "聯絡人",
-    "Contacts menu" : "聯絡人選單",
-    "Open settings menu" : "公開設定選項單",
+    "This action requires you to confirm your password" : "此操作需要您再次確認密碼",
     "Confirm your password" : "確認密碼",
+    "Confirm" : "確認",
     "Connect to your account" : "連結您的賬號",
     "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 賬號",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若你並未嘗試在新的裝置登入你的賬戶，有什麼人證在嘗試登入你的賬戶並存取你的個人資料。大多數情況你並不用作任何應對，但也可通知你的系統管理員。",
@@ -362,7 +365,6 @@ OC.L10N.register(
     "Email address" : "電郵地址",
     "Password sent!" : "密碼已傳送！",
     "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
-    "Go to %s" : "前往 %s",
     "Two-factor authentication" : "雙重認證",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的賬號已啟用進階安全機制，請選擇一個雙重認證方法：",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何已啟用的雙重認證方法，請聯絡管理員。",
@@ -384,7 +386,7 @@ OC.L10N.register(
     "The theme %s has been disabled." : "主題 %s 已經被停用。",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份數據庫、config 資料夾及數據資料夾",
     "Start update" : "開始升級",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "在大型安裝上，為了避免升級請求逾時，你也可以在安裝目錄執行下列指令：",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄下運行以下指令：",
     "Detailed logs" : "詳細記錄檔",
     "Update needed" : "需要更新",
     "Please use the command line updater because you have a big instance with more than 50 users." : "因為您有超過50名用戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
@@ -392,33 +394,44 @@ OC.L10N.register(
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁界面更新時我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
     "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
     "Maintenance mode" : "維護模式",
-    "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 安裝目前處於維護模式，可能需要一段時間才能完成。",
+    "This %s instance is currently in maintenance mode, which may take a while." : "此 %s 實例目前處於維護模式，可能需要一段時間才能完成。",
     "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "請輸入你獲得的訂閱代碼以解開用戶數量限制。有關Nextcloud企業版的詳細信息請參見我們的網站。",
-    "[%d / %d]: Checking table %s" : "[%d / %d]： 檢查數據表 %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "此伺服器沒有網際網路連線（無法與多個端點取得聯繫），有些功能，例如外部儲存、應用程式更新版通知等等將無法運作。從遠端存取資料或是寄送通知電郵可能也無法運作。建議您設定好網際網路連線以使用所有功能。",
-    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 是支援 PHP 7.2 的最後版本，Nextcloud 21 僅支援 PHP 7.3 以上的版本。",
-    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "未加載 PHP OPcache 模塊。{linkstart}為獲得更佳性能，建議↗{linked}將其加載到您的 PHP 安裝中。",
-    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache 模塊未正確配置。{linkstart}為獲得更佳性能，建議↗{linkend}在 <code>php.ini</code> 中使用以下設定：",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "數據庫中的某些列缺少對 big int 的轉換。由於更改大表上的列類型可能需要一些時間，因此無法自動更改它們。通過運行 “occ db：convert-filecache-bigint”，可以手動應用這些未決的更改。實例處於脫機狀態時需要執行此操作。有關更多詳細信息，請{linklink}關於此↗{linkend}的文檔頁面。",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "要遷移到另一個數據庫，請使用指令工具：“ occ db：convert-type”，或參閱 {linkstart} 說明書↗{linkend}。",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取，這表示 。htaccess 設定檔並未生效，我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不包防 \"{expected}\" ，這是一個潛在的安全性和隱私風險，建議調整此項設定。",
-    "Collaboratively edit office documents." : "協助編輯官方文件。",
-    "Local document editing back-end used by the Collabora Online app." : "本地文件編輯後端由Collabora Online app提供。",
-    "restricted" : "受限",
-    "invisible" : "隱藏",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "由於更新功能已在 config.php 中設定停用，請使用命令列（command line）更新系統。",
+    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "你並未設置手機國際冠碼。設置後用戶在個人檔案設定手機號碼時不必再輸入國際冠碼。若要這樣做，請新增「default_phone_region」於設定檔，允許的國家及地區請參閱 {linkstart}ISO 3166-1 code ↗{linkend} 清單。",
+    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "此伺服器沒有可用的互聯網連接（無法訪問多個端點）。 這意味著某些功能（例如掛載外部存儲、有關更新或安裝第三方應用程式的通知）將無法使用。 遠端存取檔案和發送通知電子郵件也可能不起作用。 請建立從此伺服器到互聯網的連接以享受所有功能。",
+    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "您當前正在運行PHP {version}。只要您的發行版支持，請升級PHP版本以利用 {linkstart}PHP Group↗提供的性能和安全更新{linkend}。",
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "您好像正在運行 32 位 PHP 版本。Nextcloud 需要 64 位才能運行良好。請將您的操作系統和 PHP 升級到 64 位！有關更多詳細信息，請閱讀 {linkstart} 有關的說明書頁面 ↗{linkend}。",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
+    "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
+    "Press enter to start searching" : "按 Enter 開始搜尋",
+    "Open settings menu" : "公開設定選項單",
+    "Settings" : "設定",
+    "Avatar of {fullName}" : "{fullName} 的虛擬化身",
+    "No files in here" : "此處沒有任何檔案",
+    "New folder" : "新資料夾",
+    "No more subfolders in here" : "沒有子資料夾",
+    "Name" : "名稱",
+    "Size" : "大小",
+    "Modified" : "已修改",
+    "\"{name}\" is an invalid file name." : "\"{name}\" 是無效的檔案名稱。",
+    "File name cannot be empty." : "檔案名稱不能為空。",
+    "\"/\" is not allowed inside a file name." : "不允許檔案名稱中出現 \"/\"。",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
+    "{newName} already exists" : "{newName} 已經存在",
+    "Error loading file picker template: {error}" : "載入檔案選擇器模板時出錯： {error}",
+    "Show list view" : "顯示清單視圖",
+    "Show grid view" : "顯示網格視圖",
+    "Pending" : "待辦中",
+    "Home" : "主頁",
+    "Copy to {folder}" : "複製到 {folder}",
+    "Move to {folder}" : "移動到 {folder}",
+    "Authentication required" : "必須驗證",
+    "Failed to authenticate, try again" : "驗證失敗，請再試一次",
     "File not found" : "找不到檔案",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "伺服器上找不到該文件，或許這個分享已經被刪除或是過期了？",
-    "More" : "更多",
-    "More apps menu" : "更多應用程式選單",
-    "Settings menu" : "設定選單",
-    "The password is wrong. Try again." : "密碼錯誤，請重試",
-    "Setup two-factor authentication" : "設定雙重認證",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被停用，以避免我們的免費服務負載過重。請至 nextcloud.com/enterprise 取得更多關於 Nextcloud 企業版的資訊。",
-    "You haven't added any info yet" : "您尚未新增任何資訊",
-    "{user} hasn't added any info yet" : "{user} 尚未新增任何資訊"
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "由於自動更新功能已在 config.php 檔案中設定停用，請使用命令列（command line）更新系統。",
+    "The page could not be found on the server." : "無法在伺服器上找到此頁面。",
+    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "Nextcloud 27 現已棄用 PHP 8.0。Nextcloud 28 需要 PHP 8.1 或更高版本。請盡快升級到 {linkstart} PHP Group ↗{linkend} 提供的官方支持的 PHP 版本之一。"
 },
 "nplurals=1; plural=0;");
